<?php
/**
 * Created by PhpStorm.
 * User: jderosa
 * Date: 15/01/20
 * Time: 8.59
 */

namespace FiloBlu\Rma\Helper;
use Magento\Eav\Model\AttributeRepository;
use Psr\Log\LoggerInterface;
use Magento\Eav\Model\ResourceModel\Entity\Attribute\Option\CollectionFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;


class ChangeSizeAttributeHelper
{

    const REASON_CHANGE_SIZE_LABEL='Change Size';
    const REASON_CHANGE_SIZE_ENTITY_CODE ='rma_item';
    const RMA_RESOLUTION_ATTRIBUTE_CODE = 'resolution';
    const ORDER_STATUS_CHANGESIZE_CODE = 'change_size';
    const ORDER_STATUS_CHANGESIZE_LABEL = 'Change Size Order';
    const CHANGE_SIZE_RMA_ATTRIBUTE_CODE = 'change_size';
    const RESOLUTION_CHANGE_SIZE_OPTION_CODE = 'change_size';
    const RMA_CHANGE_SIZE_OPTION_MAPPING = 'filoblu_disablerma_section/rma_group/changesize_option_mapping';
    const CHANGE_SIZE_OPTION_ENABLE = 'filoblu_disablerma_section/rma_group/rma_change_size';

    /**
     * @var AttributeRepository
     */
    protected $attributeRepository;

    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var CollectionFactory
     */
    protected $attributeOptionCollectionFactory;

    /**
     * @var ScopeConfigInterface
     */
    protected $scopeConfig;


    /**
     * ChangeSizeAttributeHelper constructor.
     * @param AttributeRepository $attributeRepository
     * @param LoggerInterface $logger
     * @param CollectionFactory $attributeOptionCollectionFactory
     * @param ScopeConfigInterface $scopeConfig
     */
    public function __construct(AttributeRepository $attributeRepository,
                                LoggerInterface $logger,
                                CollectionFactory $attributeOptionCollectionFactory,
                                ScopeConfigInterface $scopeConfig)
    {
        $this->attributeRepository = $attributeRepository;
        $this->logger = $logger;
        $this->attributeOptionCollectionFactory = $attributeOptionCollectionFactory;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @return int
     */
    public function getChangeSizeAttributeOptionId()
    {
        try
        {
            return $this->scopeConfig->getValue(self::RMA_CHANGE_SIZE_OPTION_MAPPING) ?? 0;

        }
        catch (\Exception $e)
        {
            $this->logger->critical($e->getMessage());
            return 0;
        }


    }

    /**
     * @return array|\Magento\Eav\Api\Data\AttributeOptionInterface[]|null
     */
    public function getAllResolutionOptions(){
        try
        {
            $resolution = $this->attributeRepository->get(self::REASON_CHANGE_SIZE_ENTITY_CODE,self::RMA_RESOLUTION_ATTRIBUTE_CODE);
            return $resolution->getOptions() ;
        }
        catch (\Exception $e)
        {
            $this->logger->critical($e->getMessage());
            return [];
        }
    }

    /**
     * @param int $storeId
     * @return string
     */
    public function getChangeSizeLabelByStoreId($storeId = 0){
        try{
            $chageSizeOption = $this->attributeOptionCollectionFactory->create()->addFieldToFilter('main_table.option_id',['eq'=>$this->getChangeSizeAttributeOptionId()])
                ->setStoreFilter($storeId)->getFirstItem();
            $label=$chageSizeOption->getValue() ?? $chageSizeOption->getDefaultValue();

            return $label;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return "";
        }

    }

    /**
     * @return array
     */
    public function getAllChangeSizeLabel(){
        try{
            $chageSizeOptions = $this->attributeOptionCollectionFactory->create()->addFieldToFilter('main_table.option_id',['eq'=>$this->getChangeSizeAttributeOptionId()])->distinct(true)->getItems();
            $labels = [];
            foreach ($chageSizeOptions as $option){
                $labels [] = $option->getValue();
            }
            return $labels;
        }catch (\Exception $e){
            $this->logger->critical($e->getMessage());
            return [];
        }

    }

    /**
     * @param null $websiteId
     * @return bool|mixed
     */
    public function isChangeSizeEnabled($websiteId = null){
        return $this->scopeConfig->getValue(self::CHANGE_SIZE_OPTION_ENABLE,\Magento\Store\Model\ScopeInterface::SCOPE_WEBSITE,$websiteId) ?? false;
    }



}